# Modal Form

A toolset for quick start of using forms in modal windows, flavored by access checks.

## Usage

The element to open a form in a modal window.

```php
  $form['actions']['view_filter_save'] = [
    '#type' => 'modal_form_link',
    '#class' => ViewFilterSelectForm::class,
    '#title' => $this->t('Save filter'),
    '#access' => $this->currentUser->isAuthenticated(),
    '#printed' => !$this->isFiltersApplied(),
    '#attributes' => [
      'class' => ['save-filter'],
      'data-query-parameters' => Json::encode([
        'name' => $view_name,
        'display' => $this->view->current_display,
      ]),
      'data-dialog-options' => Json::encode([
        'dialogClass' => 'modal--views-save',
        'width' => '500px',
      ]),
    ],
  ];
```

The `ViewFilterSelectForm` is a standard form implementation. As you see, to use any form in a modal window you'll simply need to install the module and add a trigger to open it. Dead simple.

### Advanced

Implement the `\Drupal\modal_form\Form\ModalFormAccessInterface` by your form and click on a trigger will first check whether a current user is permitted to see the form.

*Do not forget to add `modal_form:modal_form` to the dependencies.*
